MODULE RtrReq;
 
 IMPORT APPC;
 FROM WriteRC IMPORT WriteReturnCode;
 IMPORT Strings;
 FROM SYSTEM IMPORT SIZE;
 FROM Lib IMPORT SetReturnCode;
 IMPORT IO;
 
 CONST bufferSize = 271;
       nul        = 0C;
 
 TYPE PartString = ARRAY[0..4] OF CHAR;
 
 TYPE InqReq = RECORD
   partNum      :PartString;
 END;
 
 TYPE PartDescription = ARRAY[0..24] OF CHAR;
 TYPE Quantity        = ARRAY[0..4] OF CHAR;
 TYPE ErrorMsg        = ARRAY[0..39] OF CHAR;
 
 TYPE DBRecord = RECORD
   partds      :PartDescription;
   partq       :Quantity;
   errMsg      :ErrorMsg;
 END;
 
 CONST end = PartString('9','9','9','9','9');
 
 
 VAR
     inq                :InqReq;
     requestToSend      :BOOLEAN;
     receivedDataLength :CARDINAL;
     whatReceived       :APPC.WhatReceivedEnum;
     conversation       :APPC.ConversationHandle;
     rc                 :APPC.ReturnCode;
     dbRec              :DBRecord;
 
  BEGIN
 
  (* Allocate conversation with following:                 *)
  (* -- set synch level to none                            *)
  (* -- set system name to nul so that default will be used*)
  (* -- Name of program is RTRREQCL in Library JDET        *)
  (* -- no PIP data is sent                                *)
    rc := APPC.Allocate(
                        bufferSize,
                        APPC.syncLevelNone,
                        nul,
                        'RTRREQCL.JDET',
                        0,
                        nul,
                        conversation);
 
  (* if any errors write message indicating problem     *)
 
    IF rc <> APPC.Ok THEN
      WriteReturnCode(rc);
      SetReturnCode(255);
      HALT ;
    END;
 (* Ask for part number *)
   IO.WrStr('Enter 5-digit Part Number or 99999 To End: ');
   IO.RdStr(inq.partNum);
   IO.WrLn;
   WHILE inq.partNum <> end DO;
   APPC.ConvertToEBCDIC(inq.partNum);
 (* Send part number - module appc will handle ll and GDSID *)
    rc := APPC.SendData(
                        conversation,
                        5,
                        inq,
                        requestToSend
                     );
    IF rc <> APPC.Ok THEN
      WriteReturnCode(rc);
      SetReturnCode(255);
      HALT ;
    END;
 (* Receive response *)
    rc := APPC.ReceiveAndWait(
                        conversation,
                        SIZE(dbRec),
                        dbRec,
                        whatReceived,
                        requestToSend,
                        receivedDataLength
                        );
    IF rc <> APPC.Ok THEN
      WriteReturnCode(rc);
      SetReturnCode(255);
      HALT ;
    END;
 
  (* receive and Wait to get send indication                  *)
  (* -- set max receive length to 0 since nothing is expected *)
   rc := APPC.ReceiveAndWait(
                        conversation,
                        0,
                        dbRec,
                        whatReceived,
                        requestToSend,
                        receivedDataLength
                        );
    IF rc <> APPC.Ok THEN
      WriteReturnCode(rc);
      SetReturnCode(255);
      HALT ;
    END;
    IF whatReceived <> APPC.receivedSend THEN
      IO.WrStr('Send indicator not received from host ');
      HALT;
    END;
 (* Write received record to screen *)
  APPC.ConvertToASCII(dbRec.partds);
  APPC.ConvertToASCII(dbRec.partq);
  APPC.ConvertToASCII(dbRec.errMsg);
  IO.WrStr('Description . . . ');
  IO.WrStr(dbRec.partds);
  IO.WrLn;
  IO.WrStr('Quantity. . . . . ');
  IO.WrStr(dbRec.partq);
  IO.WrLn;
  IO.WrStr(dbRec.errMsg);
  IO.WrLn;
 
  (* ask for next part number *)
    IO.WrStr('Enter Part Number or 99999 To End: ');
    IO.RdStr(inq.partNum);
    IO.WrLn;
   END;
  (* Deallocate conversation when done *)
    rc := APPC.Deallocate(
                        conversation,
                        APPC.deallocateSynchLevel);
 
END RtrReq.
